IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'RETORNA_DIA_UTIL' AND
                 TYPE = 'FN' 		      AND
	              U.UID = O.UID           AND
	              U.NAME = USER)
DROP FUNCTION RETORNA_DIA_UTIL
GO

CREATE FUNCTION RETORNA_DIA_UTIL(
                @P_CDFILIAL  VARCHAR(04),
                @P_DTINICIAL      DATETIME,
                @P_DTFINAL        DATETIME)

RETURNS DOUBLE PRECISION
AS
BEGIN

   DECLARE @V_CONTDIA         DOUBLE PRECISION;
   DECLARE @V_DTINICIAL       DATETIME;
   DECLARE @V_IDFDIAENTREST   VARCHAR(1);
   DECLARE @V_IDFDIASAIDEST   VARCHAR(1);
   DECLARE @V_IDFDIARETIEST   VARCHAR(1);
   DECLARE @V_IDFDIACARDAP    VARCHAR(1);
   DECLARE @V_IDFDIAREQEST    VARCHAR(1);
   DECLARE @V_IDFDIAREQPLA    VARCHAR(1);
   DECLARE @V_IDFDIAEFEFAT    VARCHAR(1);
   DECLARE @V_IDFDIAEFEPLA    VARCHAR(1);
   DECLARE @V_BOFDIA          VARCHAR(1);
   DECLARE @V_DTFERIFILI      DATETIME;
   DECLARE @V_NRCARDAPIO      VARCHAR(10);
   DECLARE @V_LANCEENTR       VARCHAR(10);
   DECLARE @V_LANCESAID       VARCHAR(10);
   DECLARE @V_RETIRADA        VARCHAR(10);
   DECLARE @V_REQUISICAO      VARCHAR(10);
   DECLARE @V_SERVICO         VARCHAR(5);

   SET @V_CONTDIA   = 0;
   SET @V_DTINICIAL = @P_DTINICIAL;

   WHILE (@V_DTINICIAL <= @P_DTFINAL) BEGIN

      SELECT @V_DTFERIFILI = MAX(DTFERIFILI)
        FROM FERIFILI
       WHERE CDFILIAL   = @P_CDFILIAL
         AND DTFERIFILI = @V_DTINICIAL;

      IF @V_DTFERIFILI IS NULL BEGIN
         SET @V_CONTDIA = @V_CONTDIA + 1;
      END
      ELSE BEGIN
         SET @V_BOFDIA        = 'F';
         SET @V_IDFDIAENTREST = NULL;
         SET @V_IDFDIASAIDEST = NULL;
         SET @V_IDFDIARETIEST = NULL;
         SET @V_IDFDIACARDAP  = NULL;
         SET @V_IDFDIAREQEST  = NULL;
         SET @V_IDFDIAREQPLA  = NULL;
         SET @V_IDFDIAEFEFAT  = NULL;
         SET @V_IDFDIAEFEPLA  = NULL;

         SELECT @V_IDFDIAENTREST = IDFDIAENTREST, @V_IDFDIASAIDEST = IDFDIASAIDEST,
                @V_IDFDIARETIEST = IDFDIARETIEST, @V_IDFDIACARDAP  = IDFDIACARDAP,
                @V_IDFDIAREQEST  = IDFDIAREQEST,  @V_IDFDIAREQPLA  = IDFDIAREQPLA,
                @V_IDFDIAEFEFAT  = IDFDIAEFEFAT,  @V_IDFDIAEFEPLA  = IDFDIAEFEPLA

           FROM PARAMFILIAL
          WHERE CDFILIAL = @P_CDFILIAL;

         IF (@V_IDFDIAENTREST = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica os lanamentos de entrada*/


            SELECT @V_LANCEENTR = MAX(NRLANCESTQ)
              FROM LANCTOESTOQ L
             WHERE L.CDFILIMOVI   = @P_CDFILIAL
               AND L.DTLANCESTQ   = @V_DTINICIAL
               AND L.IDTPLANCTO  IN ('0','1','2');

            IF @V_LANCEENTR IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIASAIDEST = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica os lanamentos de saida*/

            SELECT @V_LANCESAID = MAX(NRLANCESTQ)
              FROM LANCTOESTOQ L
             WHERE L.CDFILIMOVI   = @P_CDFILIAL
               AND L.DTLANCESTQ   = @V_DTINICIAL
               AND L.IDTPLANCTO  IN ('0','1','4');

            IF @V_LANCESAID IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIARETIEST = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica os lanamentos de retirada*/

            SELECT @V_RETIRADA = MAX(A.NRLANCESTQ)
              FROM
                   (SELECT L.NRLANCESTQ
                      FROM LANCTOESTOQ L, RETIRADA R
                     WHERE L.CDFILIMOVI   = @P_CDFILIAL
                       AND L.DTLANCESTQ   = @V_DTINICIAL
                       AND L. IDTPLANCTO  = '3'
                       AND L.CDFILIAL     = R.CDFILANCESTQ
                       AND L.NRLANCESTQ   = R.NRLANCESTQ

                     UNION ALL

                    SELECT L.NRLANCESTQ
                      FROM LANCTOESTOQ L, RETIRADAESTO R
                     WHERE L.CDFILIMOVI   = @P_CDFILIAL
                       AND L.DTLANCESTQ   = @V_DTINICIAL
                       AND L. IDTPLANCTO  = '3'
                       AND L.CDFILIAL     = R.CDFILIALLAN
                       AND L.NRLANCESTQ   = R.NRLANCESTQ)A

            IF @V_RETIRADA IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIACARDAP = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica se tem cardapio*/

            SELECT @V_NRCARDAPIO = MAX(NRCARDAPIO)
              FROM CARDADIA
             WHERE CDFILIAL    = @P_CDFILIAL
               AND DTCARDAPIO  = @V_DTINICIAL;

            IF @V_NRCARDAPIO IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIAREQEST = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica se tem requisio de estoque*/

            SELECT @V_REQUISICAO = MAX(NRREQUESTO)
              FROM REQUESTO R
             WHERE R.CDFILIAL    = @P_CDFILIAL
               AND R.DTREQUESTO  = @V_DTINICIAL;

            IF @V_REQUISICAO IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIAREQPLA = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica se tem requisio de planejamento*/

            SELECT @V_REQUISICAO = MAX(NRREQUEXTR)
              FROM PREVRETI PR
             WHERE PR.CDFILIAL   = @P_CDFILIAL
               AND PR.DTPREVRETI = @V_DTINICIAL;


            IF @V_REQUISICAO IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIAEFEFAT = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica se tem efetivos lanados*/

            SELECT @V_SERVICO = MAX(A.CDSERVFILI)
              FROM
                  (SELECT CDSERVFILI
                     FROM EFECLIFAT
                    WHERE CDFILIAL   = @P_CDFILIAL
                      AND DTFATURAM  = @V_DTINICIAL

                    UNION ALL

                    SELECT CDSERVFILI
                      FROM EFECLIFATTUR
                     WHERE CDFILIAL     = @P_CDFILIAL
                       AND DTFATURAMTUR = @V_DTINICIAL)A

            IF @V_SERVICO IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF (@V_IDFDIAEFEPLA = 'S') AND (@V_BOFDIA = 'F') BEGIN /*verifica se tem efetivos por cliente*/

            SELECT @V_SERVICO = MAX(CDSERVFILI)
              FROM EFETCLIE
             WHERE CDFILIAL     = @P_CDFILIAL
               AND DTEFETCLIE   = @V_DTINICIAL;

            IF @V_SERVICO IS NOT NULL BEGIN
               SET @V_BOFDIA = 'V';
            END;
         END;

         IF @V_BOFDIA = 'V' BEGIN
            SET @V_CONTDIA = @V_CONTDIA + 1;
         END;

      END;
      
      SET @V_DTINICIAL = @V_DTINICIAL + 1;
   END;

   RETURN(@V_CONTDIA);

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'RETORNA_DIA_UTIL','5.11.000';
GO
