/*
Descrio: 

Procedure destinada ao clculo da alquota do simples nacional

Parmetros:

(IN) P_CDEMPRESA - Cdigo da empresa
(IN) P_CDTIPOOPER - Cdigo do tipo de operao
(IN) P_INIVALID - Data que ser utilizada para o clculo da alquota
(IN) P_CDFISOPEITEM - Cdigo fiscal da operao (sem o 1 dgito do CFOP)
(IN) @P_CDIMPOSTONFE - Cdigo do imposto NF-e
(IN) P_VRSUBLIMITESN - Valor do sublimite da empresa
(IN) P_RATEIODIFERENCA - identifica se o processo ser utilizado para clculo da alquota ou apenas para validar a diferena entre a aliquota efetiva e o 
(OUT) P_RBT12 - Retorno da receita bruta total do ltimos 12 meses
(OUT) P_RBA - Retorno da receita bruta acumulada no ano corrente
(OUT) P_CDSIMPLESNACIONAL - Retorno da tabela do simples nacional que a empresa se enquadra
(OUT) P_CDFAIXA - Retorno da faixa de valores da tabela do simples nacional que a empresa se enquadra
(OUT) P_VRALIQUOTASN - Retorno da alquota do imposto

Criao:

Gleydson Israel da Silva Gazola

Observaes:

Em resumo o simples nacional se define na seguinte frmula:

AE = (RBT12 x AliqNo - PD) / RBT12

Onde:
AE = alquota efetiva
RBT12 = receita bruta total do ltimos 12 meses
AliqNo = alquota nominal da faixa
PD = parcela a deduzir

Aps encontrar a aliquota efetiva  s calcular a repartio dos tributos com a seguinte frmula:

Trib = AE * AliqTrib

Onde:
AliqFinal = Alquota final do imposto
AE = Alquota efetiva
AliqTrib = Alquota nominal do imposto
*/

IF EXISTS(SELECT * 
            FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCULA_ALIQUOTA_SN'  
             AND TYPE   = 'P'
             AND U.UID  = O.UID
             AND U.NAME = USER)
   DROP PROCEDURE CALCULA_ALIQUOTA_SN
GO

CREATE PROCEDURE CALCULA_ALIQUOTA_SN(
   @P_CDEMPRESA VARCHAR(02),
   @P_CDTIPOOPER VARCHAR(02),
   @P_INIVALID DATETIME,
   @P_CDFISOPEITEM VARCHAR(03),
   @P_CDIMPOSTONFE VARCHAR(02),
   @P_VRSUBLIMITESN DOUBLE PRECISION,
   @P_RATEIODIFERENCA VARCHAR(01),
   @P_RBT12 DOUBLE PRECISION OUTPUT,
   @P_RBA DOUBLE PRECISION OUTPUT,
   @P_CDSIMPLESNACIONAL VARCHAR(05) OUTPUT,
   @P_CDFAIXA VARCHAR(05) OUTPUT,
   @P_VRALIQUOTASN DOUBLE PRECISION OUTPUT)
AS
   /* VARIVEIS DA 1 FAIXA */
   DECLARE @V_CD1FAIXA VARCHAR(05);
   DECLARE @V_VRALIQSIMPLES1FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIR1FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO1FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPERRATISS1FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVA1FAIXA DOUBLE PRECISION;
   /* VARIVEIS DA 2 FAIXA */
   DECLARE @V_CD2FAIXA VARCHAR(05);
   DECLARE @V_VRALIQSIMPLES2FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIR2FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO2FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPERRATISS2FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVA2FAIXA DOUBLE PRECISION;
   /* VARIVEIS DA 3 FAIXA */
   DECLARE @V_CD3FAIXA VARCHAR(05);
   DECLARE @V_VRALIQSIMPLES3FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIR3FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO3FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPERRATISS3FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVA3FAIXA DOUBLE PRECISION;
   /* VARIVEIS DA 4 FAIXA */
   DECLARE @V_CD4FAIXA VARCHAR(05);
   DECLARE @V_VRALIQSIMPLES4FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIR4FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO4FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPERRATISS4FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVA4FAIXA DOUBLE PRECISION;
   /* VARIVEIS DA 5 FAIXA */
   DECLARE @V_CD5FAIXA VARCHAR(05);
   DECLARE @V_VRALIQSIMPLES5FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIR5FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO5FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPERRATISS5FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVA5FAIXA DOUBLE PRECISION;
   /* VARIVEIS DA 6 FAIXA */
   DECLARE @V_CD6FAIXA VARCHAR(05);
   DECLARE @V_VRALIQSIMPLES6FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIR6FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO6FAIXA DOUBLE PRECISION;
   DECLARE @V_VRPERRATISS6FAIXA DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVA6FAIXA DOUBLE PRECISION;
   /* VARIVEIS AUXILIARES DAS FAIXAS */
   DECLARE @V_CDFAIXAAUX VARCHAR(05);
   DECLARE @V_VRALIQSIMPLESFAIXAAUX DOUBLE PRECISION;
   DECLARE @V_VRPARCDEDUZIRFAIXAAUX DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTOFAIXAAUX DOUBLE PRECISION;
   DECLARE @V_VRPERRATISSFAIXAAUX DOUBLE PRECISION;
   DECLARE @V_VRALIQEFETIVAFAIXAAUX DOUBLE PRECISION;

   /* VARIVEIS DO CURSOR C_RATEIO_IMPOSTO */
   DECLARE @C_RATEIO_IMPOSTO_CDIMPOSTONFE VARCHAR(02);
   DECLARE @C_RATEIO_IMPOSTO_VRALIQSIMPLES DOUBLE PRECISION;
   DECLARE @C_RATEIO_IMPOSTO_VRPERRATISS DOUBLE PRECISION;

   DECLARE @V_FAIXAENQUADRADA NUMERIC;
   DECLARE @V_CDSIMPLESNACIONAL VARCHAR(05);
   DECLARE @V_RBT12 DOUBLE PRECISION; 
   DECLARE @V_RBA DOUBLE PRECISION; 
   DECLARE @V_QTDEMESES NUMERIC;
   DECLARE @V_VRALIQIMPOSTOISS DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTOISSAUX DOUBLE PRECISION;
   DECLARE @V_VRALIQIMPOSTO DOUBLE PRECISION;
   DECLARE @V_CDIMPOSTOMAXALIQUOTA VARCHAR(02);
   DECLARE @V_VRALIQSIMPLESRATEIO DOUBLE PRECISION;
   DECLARE @V_RATEIADIFISS VARCHAR(01);
   DECLARE @V_VRALIQSIMPLESISSAUX DOUBLE PRECISION;
   DECLARE @V_RBT12VALIDA DOUBLE PRECISION;
   DECLARE @V_RBAVALIDA DOUBLE PRECISION;
   DECLARE @V_CDSIMPLESNACIONALVALIDA VARCHAR(05);
   DECLARE @V_CDFAIXAVALIDA VARCHAR(05);
   DECLARE @V_VRALIQUOTASNVALIDA DOUBLE PRECISION;
BEGIN

   SET @V_RATEIADIFISS = 'N';

   SELECT @V_CDSIMPLESNACIONAL = MAX(C.CDSIMPLESNACIONAL)
     FROM CFOPSIMPLESNAC C, SIMPLESNACIONAL S
    WHERE C.CDCFOPPADRAO = @P_CDFISOPEITEM
      AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL
      AND S.DTINIVIGENCIA <= @P_INIVALID
      AND ISNULL(S.DTFIMVIGENCIA, @P_INIVALID) >= @P_INIVALID;

   IF @V_CDSIMPLESNACIONAL IS NULL BEGIN
     SELECT @V_CDSIMPLESNACIONAL = MAX(S.CDSIMPLESNACIONAL)
       FROM SIMPLESNACIONAL S, EMPRSIMPLESNAC E, TPOPERSIMPLESNAC T
      WHERE S.CDSIMPLESNACIONAL = E.CDSIMPLESNACIONAL
        AND E.CDEMPRESA = @P_CDEMPRESA
        AND S.CDSIMPLESNACIONAL = T.CDSIMPLESNACIONAL
        AND T.CDTIPOOPER = @P_CDTIPOOPER
        AND T.IDENTRSAIDOP = 'S'
        AND S.DTINIVIGENCIA  <= @P_INIVALID
        AND ISNULL(S.DTFIMVIGENCIA, @P_INIVALID) >= @P_INIVALID;
   END;

   IF @V_CDSIMPLESNACIONAL IS NOT NULL BEGIN
      SET @V_FAIXAENQUADRADA = 0;
      SET @V_QTDEMESES = 0;

      --RECEITA BRUTA ACUMULADA NO ANO CORRENTE
      SELECT @V_RBA = ISNULL(SUM(ISNULL(VRRECEITABR, 0)), 0)
        FROM RECEITABRUTA
       WHERE CDEMPRESA = @P_CDEMPRESA
         AND DTREFRECEITABR BETWEEN '01/01/' + CAST(YEAR(@P_INIVALID) AS CHAR(04)) AND EOMONTH(DATEADD(MM, -1, @P_INIVALID)) /* NO CONSIDERA O MS ATUAL */
         AND IDSTATUSMES = 'B';

      --RECEITA BRUTA TOTAL DOS LTIMOS 12 MESES
      SELECT @V_RBT12 = ISNULL(SUM(ISNULL(VRRECEITABR, 0)), 0)
        FROM RECEITABRUTA
       WHERE CDEMPRESA = @P_CDEMPRESA
         AND DTREFRECEITABR BETWEEN DATEADD(MONTH, DATEDIFF(MONTH, 0, DATEADD(MM, -12, @P_INIVALID)), 0) AND EOMONTH(DATEADD(MM, -1, @P_INIVALID)) /* NO CONSIDERA O MS ATUAL */
         AND IDSTATUSMES = 'B';

      --SEGUNDO A LEGISLAO, CASO NO TENHA FATURAMENTO NOS LTIMOS 12 MESES CONSIDERAR VALOR 1
      IF @V_RBT12 = 0 BEGIN
         SET @V_RBT12 = 1;
      END;

      SELECT @V_QTDEMESES = COUNT(DISTINCT DTREFRECEITABR)
        FROM RECEITABRUTA
       WHERE CDEMPRESA = @P_CDEMPRESA
         AND DTREFRECEITABR BETWEEN DATEADD(MONTH, DATEDIFF(MONTH, 0, DATEADD(MM, -12, @P_INIVALID)), 0) AND EOMONTH(DATEADD(MM, -1, @P_INIVALID)) /* NO CONSIDERA O MS ATUAL */
         AND IDSTATUSMES = 'B';

      IF (@V_QTDEMESES > 0) AND (@V_QTDEMESES < 12) BEGIN
         SET @V_RBT12 = ROUND((@V_RBT12 / @V_QTDEMESES) * 12, 2);
      END;

      --IDENTIFICANDO A FAIXA DE FATURAMENTO 
      IF @V_RBT12 <= 180000 BEGIN
         SET @V_FAIXAENQUADRADA = 1;
      END ELSE IF (@V_RBT12 > 180000) AND (@V_RBT12 <= 360000) BEGIN
         SET @V_FAIXAENQUADRADA = 2;
      END ELSE IF (@V_RBT12 > 360000) AND (@V_RBT12 <= 720000) BEGIN
         SET @V_FAIXAENQUADRADA = 3;
      END ELSE IF (@V_RBT12 > 720000) AND (@V_RBT12 <= 1800000) BEGIN
         SET @V_FAIXAENQUADRADA = 4;
      END ELSE IF (@V_RBT12 > 1800000) AND (@V_RBT12 <= 3600000) BEGIN
         SET @V_FAIXAENQUADRADA = 5;
      END ELSE IF (@V_RBT12 > 3600000) AND (@V_RBT12 <= 4800000) BEGIN
         SET @V_FAIXAENQUADRADA = 6;
      END ELSE BEGIN
         SET @V_FAIXAENQUADRADA = 0;
      END;

      IF @V_FAIXAENQUADRADA = 1 BEGIN --CARREGANDO AS INFORMAES DA 1 FAIXA
         SELECT @V_CD1FAIXA = F.CDFAIXA,
                @V_VRALIQSIMPLES1FAIXA = ISNULL(F.VRALIQSIMPLES, 0),
                @V_VRPARCDEDUZIR1FAIXA = ISNULL(F.VRPARCDEDUZIR, 0),
                @V_VRALIQIMPOSTO1FAIXA = ISNULL(I.VRALIQSIMPLES, 0),
                @V_VRPERRATISS1FAIXA = ISNULL(I.VRPERRATISS, 0),
                @V_VRALIQEFETIVA1FAIXA = ((((@V_RBT12 * ISNULL(F.VRALIQSIMPLES, 0) / 100) - ISNULL(F.VRPARCDEDUZIR, 0)) / CASE @V_RBT12 WHEN 0 THEN 1 ELSE @V_RBT12 END) * 100)
           FROM FAIXASIMPLESNAC F JOIN IMPSIMPLESFAIXA I ON (F.CDSIMPLESNACIONAL = I.CDSIMPLESNACIONAL)
                                                        AND (F.CDFAIXA = I.CDFAIXA)
                                  JOIN IMPOSTO IP ON (I.CDIMPOSTO = IP.CDIMPOSTO)
          WHERE F.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
            AND IP.CDIMPOSTONFE = @P_CDIMPOSTONFE
            AND ROUND(F.VRINICIAL, 0, 1) = 0
            AND ROUND(F.VRFINAL, 0, 1) = 180000;
      END;

      IF @V_FAIXAENQUADRADA = 2 BEGIN --CARREGANDO AS INFORMAES DA 2 FAIXA
         SELECT @V_CD2FAIXA = F.CDFAIXA,
                @V_VRALIQSIMPLES2FAIXA = ISNULL(F.VRALIQSIMPLES, 0),
                @V_VRPARCDEDUZIR2FAIXA = ISNULL(F.VRPARCDEDUZIR, 0),
                @V_VRALIQIMPOSTO2FAIXA = ISNULL(I.VRALIQSIMPLES, 0),
                @V_VRPERRATISS2FAIXA = ISNULL(I.VRPERRATISS, 0),
                @V_VRALIQEFETIVA2FAIXA = ((((@V_RBT12 * ISNULL(F.VRALIQSIMPLES, 0) / 100) - ISNULL(F.VRPARCDEDUZIR, 0)) / CASE @V_RBT12 WHEN 0 THEN 1 ELSE @V_RBT12 END) * 100)
           FROM FAIXASIMPLESNAC F JOIN IMPSIMPLESFAIXA I ON (F.CDSIMPLESNACIONAL = I.CDSIMPLESNACIONAL)
                                                        AND (F.CDFAIXA = I.CDFAIXA)
                                  JOIN IMPOSTO IP ON (I.CDIMPOSTO = IP.CDIMPOSTO)
          WHERE F.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
            AND IP.CDIMPOSTONFE = @P_CDIMPOSTONFE
            AND ROUND(F.VRINICIAL, 0, 1) = 180000
            AND ROUND(F.VRFINAL, 0, 1) = 360000;
      END;

      IF @V_FAIXAENQUADRADA = 3 BEGIN --CARREGANDO AS INFORMAES DA 3 FAIXA
         SELECT @V_CD3FAIXA = F.CDFAIXA,
                @V_VRALIQSIMPLES3FAIXA = ISNULL(F.VRALIQSIMPLES, 0),
                @V_VRPARCDEDUZIR3FAIXA = ISNULL(F.VRPARCDEDUZIR, 0),
                @V_VRALIQIMPOSTO3FAIXA = ISNULL(I.VRALIQSIMPLES, 0),
                @V_VRPERRATISS3FAIXA = ISNULL(I.VRPERRATISS, 0),
                @V_VRALIQEFETIVA3FAIXA = ((((@V_RBT12 * ISNULL(F.VRALIQSIMPLES, 0) / 100) - ISNULL(F.VRPARCDEDUZIR, 0)) / CASE @V_RBT12 WHEN 0 THEN 1 ELSE @V_RBT12 END) * 100)
           FROM FAIXASIMPLESNAC F JOIN IMPSIMPLESFAIXA I ON (F.CDSIMPLESNACIONAL = I.CDSIMPLESNACIONAL)
                                                        AND (F.CDFAIXA = I.CDFAIXA)
                                  JOIN IMPOSTO IP ON (I.CDIMPOSTO = IP.CDIMPOSTO)
          WHERE F.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
            AND IP.CDIMPOSTONFE = @P_CDIMPOSTONFE
            AND ROUND(F.VRINICIAL, 0, 1) = 360000
            AND ROUND(F.VRFINAL, 0, 1) = 720000;
      END;

      --QUANDO O FATURAMENTO DA EMPRESA ESTIVER NA 5 OU 6 FAIXA SER CARREGADO TAMBM O DADOS DA 4. ISTO PORQUE EXISTEM SITUAES EM QUE ELE SER UTILIZADO PARA REALIZAR ALGUM CLCULO
      IF @V_FAIXAENQUADRADA IN (4, 5, 6) BEGIN --CARREGANDO AS INFORMAES DA 4 FAIXA
         SELECT @V_CD4FAIXA = F.CDFAIXA,
                @V_VRALIQSIMPLES4FAIXA = ISNULL(F.VRALIQSIMPLES, 0),
                @V_VRPARCDEDUZIR4FAIXA = ISNULL(F.VRPARCDEDUZIR, 0),
                @V_VRALIQIMPOSTO4FAIXA = ISNULL(I.VRALIQSIMPLES, 0),
                @V_VRPERRATISS4FAIXA = ISNULL(I.VRPERRATISS, 0),
                @V_VRALIQEFETIVA4FAIXA = ((((@V_RBT12 * ISNULL(F.VRALIQSIMPLES, 0) / 100) - ISNULL(F.VRPARCDEDUZIR, 0)) / CASE @V_RBT12 WHEN 0 THEN 1 ELSE @V_RBT12 END) * 100)
           FROM FAIXASIMPLESNAC F JOIN IMPSIMPLESFAIXA I ON (F.CDSIMPLESNACIONAL = I.CDSIMPLESNACIONAL)
                                                        AND (F.CDFAIXA = I.CDFAIXA)
                                  JOIN IMPOSTO IP ON (I.CDIMPOSTO = IP.CDIMPOSTO)
          WHERE F.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
            AND IP.CDIMPOSTONFE = @P_CDIMPOSTONFE
            AND ROUND(F.VRINICIAL, 0 , 1) = 720000
            AND ROUND(F.VRFINAL, 0 , 1) = 1800000;
      END;

      --QUANDO O FATURAMENTO DA EMPRESA ESTIVER NA 6 FAIXA SER CARREGADO TAMBM O DADOS DA 5. ISTO PORQUE EXISTEM SITUAES EM QUE ELE SER UTILIZADO PARA REALIZAR ALGUM CLCULO
      IF @V_FAIXAENQUADRADA IN (5, 6) BEGIN --CARREGANDO AS INFORMAES DA 5 FAIXA
         SELECT @V_CD5FAIXA = F.CDFAIXA,
                @V_VRALIQSIMPLES5FAIXA = ISNULL(F.VRALIQSIMPLES, 0),
                @V_VRPARCDEDUZIR5FAIXA = ISNULL(F.VRPARCDEDUZIR, 0),
                @V_VRALIQIMPOSTO5FAIXA = ISNULL(I.VRALIQSIMPLES, 0),
                @V_VRPERRATISS5FAIXA = ISNULL(I.VRPERRATISS, 0),
                @V_VRALIQEFETIVA5FAIXA = ((((@V_RBT12 * ISNULL(F.VRALIQSIMPLES, 0) / 100) - ISNULL(F.VRPARCDEDUZIR, 0)) / CASE @V_RBT12 WHEN 0 THEN 1 ELSE @V_RBT12 END) * 100)
           FROM FAIXASIMPLESNAC F JOIN IMPSIMPLESFAIXA I ON (F.CDSIMPLESNACIONAL = I.CDSIMPLESNACIONAL)
                                                        AND (F.CDFAIXA = I.CDFAIXA)
                                  JOIN IMPOSTO IP ON (I.CDIMPOSTO = IP.CDIMPOSTO)
          WHERE F.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
            AND IP.CDIMPOSTONFE = @P_CDIMPOSTONFE
            AND ROUND(F.VRINICIAL, 0 , 1) = 1800000
            AND ROUND(F.VRFINAL, 0 , 1) = 3600000;
      END;

      IF @V_FAIXAENQUADRADA = 6 BEGIN --CARREGANDO AS INFORMAES DA 6 FAIXA
            SELECT @V_CD6FAIXA = F.CDFAIXA,
                   @V_VRALIQSIMPLES6FAIXA = ISNULL(F.VRALIQSIMPLES, 0),
                   @V_VRPARCDEDUZIR6FAIXA = ISNULL(F.VRPARCDEDUZIR, 0),
                   @V_VRALIQIMPOSTO6FAIXA = ISNULL(I.VRALIQSIMPLES, 0),
                   @V_VRPERRATISS6FAIXA = ISNULL(I.VRPERRATISS, 0),
                   @V_VRALIQEFETIVA6FAIXA = ((((@V_RBT12 * ISNULL(F.VRALIQSIMPLES, 0) / 100) - ISNULL(F.VRPARCDEDUZIR, 0)) / CASE @V_RBT12 WHEN 0 THEN 1 ELSE @V_RBT12 END) * 100)
              FROM FAIXASIMPLESNAC F JOIN IMPSIMPLESFAIXA I ON (F.CDSIMPLESNACIONAL = I.CDSIMPLESNACIONAL)
                                                           AND (F.CDFAIXA = I.CDFAIXA)
                                     JOIN IMPOSTO IP ON (I.CDIMPOSTO = IP.CDIMPOSTO)
             WHERE F.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
               AND IP.CDIMPOSTONFE = @P_CDIMPOSTONFE
               AND ROUND(F.VRINICIAL, 0 , 1) = 3600000
               AND ROUND(F.VRFINAL, 0 , 1) = 4800000;
      END;

      --GRAVANDO EM UMA VARIVEL AUXILIAR OS DADOS DA FAIXA PRINCIPAL DO FATURAMENTO
      IF @V_RBT12 > 0 BEGIN
         IF @V_FAIXAENQUADRADA = 1 BEGIN
            SET @V_CDFAIXAAUX = @V_CD1FAIXA;
            SET @V_VRALIQSIMPLESFAIXAAUX = @V_VRALIQSIMPLES1FAIXA;
            SET @V_VRPARCDEDUZIRFAIXAAUX = @V_VRPARCDEDUZIR1FAIXA;
            SET @V_VRALIQIMPOSTOFAIXAAUX = @V_VRALIQIMPOSTO1FAIXA;
            SET @V_VRPERRATISSFAIXAAUX = @V_VRPERRATISS1FAIXA;
            SET @V_VRALIQEFETIVAFAIXAAUX = @V_VRALIQEFETIVA1FAIXA;
         END ELSE IF @V_FAIXAENQUADRADA = 2 BEGIN
            SET @V_CDFAIXAAUX = @V_CD2FAIXA;
            SET @V_VRALIQSIMPLESFAIXAAUX = @V_VRALIQSIMPLES2FAIXA;
            SET @V_VRPARCDEDUZIRFAIXAAUX = @V_VRPARCDEDUZIR2FAIXA;
            SET @V_VRALIQIMPOSTOFAIXAAUX = @V_VRALIQIMPOSTO2FAIXA;
            SET @V_VRPERRATISSFAIXAAUX = @V_VRPERRATISS2FAIXA;
            SET @V_VRALIQEFETIVAFAIXAAUX = @V_VRALIQEFETIVA2FAIXA;
         END ELSE IF @V_FAIXAENQUADRADA = 3 BEGIN
            SET @V_CDFAIXAAUX = @V_CD3FAIXA;
            SET @V_VRALIQSIMPLESFAIXAAUX = @V_VRALIQSIMPLES3FAIXA;
            SET @V_VRPARCDEDUZIRFAIXAAUX = @V_VRPARCDEDUZIR3FAIXA;
            SET @V_VRALIQIMPOSTOFAIXAAUX = @V_VRALIQIMPOSTO3FAIXA;
            SET @V_VRPERRATISSFAIXAAUX = @V_VRPERRATISS3FAIXA;
            SET @V_VRALIQEFETIVAFAIXAAUX = @V_VRALIQEFETIVA3FAIXA;
         END ELSE IF @V_FAIXAENQUADRADA = 4 BEGIN
            SET @V_CDFAIXAAUX = @V_CD4FAIXA;
            SET @V_VRALIQSIMPLESFAIXAAUX = @V_VRALIQSIMPLES4FAIXA;
            SET @V_VRPARCDEDUZIRFAIXAAUX = @V_VRPARCDEDUZIR4FAIXA;
            SET @V_VRALIQIMPOSTOFAIXAAUX = @V_VRALIQIMPOSTO4FAIXA;
            SET @V_VRPERRATISSFAIXAAUX = @V_VRPERRATISS4FAIXA;
            SET @V_VRALIQEFETIVAFAIXAAUX = @V_VRALIQEFETIVA4FAIXA;
         END ELSE IF @V_FAIXAENQUADRADA = 5 BEGIN
            SET @V_CDFAIXAAUX = @V_CD5FAIXA;
            SET @V_VRALIQSIMPLESFAIXAAUX = @V_VRALIQSIMPLES5FAIXA;
            SET @V_VRPARCDEDUZIRFAIXAAUX = @V_VRPARCDEDUZIR5FAIXA;
            SET @V_VRALIQIMPOSTOFAIXAAUX = @V_VRALIQIMPOSTO5FAIXA;
            SET @V_VRPERRATISSFAIXAAUX = @V_VRPERRATISS5FAIXA;
            SET @V_VRALIQEFETIVAFAIXAAUX = @V_VRALIQEFETIVA5FAIXA;
         END ELSE IF @V_FAIXAENQUADRADA = 6 BEGIN
            SET @V_CDFAIXAAUX = @V_CD6FAIXA;
            SET @V_VRALIQSIMPLESFAIXAAUX = @V_VRALIQSIMPLES6FAIXA;
            SET @V_VRPARCDEDUZIRFAIXAAUX = @V_VRPARCDEDUZIR6FAIXA;
            SET @V_VRALIQIMPOSTOFAIXAAUX = @V_VRALIQIMPOSTO6FAIXA;
            SET @V_VRPERRATISSFAIXAAUX = @V_VRPERRATISS6FAIXA;
            SET @V_VRALIQEFETIVAFAIXAAUX = @V_VRALIQEFETIVA6FAIXA;
         END;

         --CALCULANDO O VALOR DA ALQUOTA DO IMPOSTO
         IF @P_CDIMPOSTONFE IN ('00', '31') BEGIN
            IF @V_RBA <= (@P_VRSUBLIMITESN * 1.2) BEGIN
               IF @V_RBA <= @P_VRSUBLIMITESN BEGIN
                  IF (@V_RBT12 >= 3600000) BEGIN
                     SET @V_VRALIQIMPOSTO = @V_VRALIQEFETIVA5FAIXA * (@V_VRALIQIMPOSTO5FAIXA / 100);
                  END ELSE BEGIN
                     SET @V_VRALIQIMPOSTO = @V_VRALIQEFETIVAFAIXAAUX * (@V_VRALIQIMPOSTOFAIXAAUX / 100);
                  END;
               END ELSE BEGIN
                  IF @P_VRSUBLIMITESN = 3600000 BEGIN
                     SET @V_VRALIQIMPOSTO = ((((3600000 * @V_VRALIQSIMPLES5FAIXA / 100) - @V_VRPARCDEDUZIR5FAIXA) / 3600000) * 100) * (@V_VRALIQIMPOSTO5FAIXA / 100);
                  END ELSE BEGIN 
                     SET @P_VRSUBLIMITESN = 1800000;
                     SET @V_VRALIQIMPOSTO = ((((1800000 * @V_VRALIQSIMPLES4FAIXA / 100) - @V_VRPARCDEDUZIR4FAIXA) / 1800000) * 100) * (@V_VRALIQIMPOSTO4FAIXA / 100);
                  END;
               END;
            END;
         END ELSE BEGIN
            SET @V_VRALIQIMPOSTO = @V_VRALIQEFETIVAFAIXAAUX * (@V_VRALIQIMPOSTOFAIXAAUX / 100);
         END;

         IF @P_CDIMPOSTONFE = 31 BEGIN
            --SEGUNDO A LEGISLAO A ALQUOTA DO ISS NO PODE ULTRAPASSAR OS 5%
            IF @V_VRALIQIMPOSTO > 5 BEGIN
               SET @V_VRALIQIMPOSTO = 5;
            END;
         END ELSE BEGIN
            --VERIFICANDO SE EXISTE A INCIDNCIA DO ISS NA OPERAO 
            SELECT @V_VRALIQIMPOSTOISS = ISNULL(SUM(VRALIQSIMPLES),0)
              FROM IMPSIMPLESFAIXA I, IMPOSTO II
             WHERE I.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
               AND I.CDFAIXA = CASE WHEN @V_FAIXAENQUADRADA IN (1, 2, 3, 4, 5) THEN @V_CDFAIXAAUX WHEN @V_FAIXAENQUADRADA IN (6) THEN @V_CD5FAIXA END
               AND I.CDIMPOSTO = II.CDIMPOSTO
               AND II.CDIMPOSTONFE = 31;

            IF @V_VRALIQIMPOSTOISS > 0 BEGIN
               --CALCULANDO A ALQUOTA DO ISS 
               IF @V_FAIXAENQUADRADA IN (1, 2, 3, 4, 5) BEGIN
                  IF @V_RBA <= (@P_VRSUBLIMITESN * 1.2) BEGIN
                     SET @V_VRALIQIMPOSTOISS = @V_VRALIQEFETIVAFAIXAAUX * (@V_VRALIQIMPOSTOISS / 100);
                     SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQIMPOSTOISS;
                  END ELSE BEGIN
                     SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQEFETIVAFAIXAAUX * (@V_VRALIQIMPOSTOISS / 100);
                     SET @V_VRALIQIMPOSTOISS = 0;
                  END;
               END ELSE BEGIN 
                  IF @V_FAIXAENQUADRADA IN (6) BEGIN
                     IF @V_RBA <= (@P_VRSUBLIMITESN * 1.2) BEGIN
                        IF @V_RBA <= @P_VRSUBLIMITESN BEGIN
                           IF (@V_RBT12 >= 3600000) BEGIN
                              SET @V_VRALIQIMPOSTOISS = @V_VRALIQEFETIVA5FAIXA * (@V_VRALIQIMPOSTOISS / 100);
                              SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQIMPOSTOISS;
                           END ELSE BEGIN
                              SET @V_VRALIQIMPOSTOISS = @V_VRALIQEFETIVAFAIXAAUX * (@V_VRALIQIMPOSTOISS / 100);
                              SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQIMPOSTOISS;
                           END;
                        END ELSE BEGIN
                           IF @P_VRSUBLIMITESN = 3600000 BEGIN
                              SET @V_VRALIQIMPOSTOISS = ((((3600000 * @V_VRALIQSIMPLES5FAIXA / 100) - @V_VRPARCDEDUZIR5FAIXA) / 3600000) * 100) * (@V_VRALIQIMPOSTOISS / 100);
                              SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQIMPOSTOISS;
                           END ELSE BEGIN 
                              IF @P_VRSUBLIMITESN = 1800000 BEGIN
                                 SET @V_VRALIQIMPOSTOISS = ((((1800000 * @V_VRALIQSIMPLES5FAIXA / 100) - @V_VRPARCDEDUZIR5FAIXA) / 1800000) * 100) * (@V_VRALIQIMPOSTOISS / 100);
                                 SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQIMPOSTOISS; 
                              END;
                           END;
                        END;
                     END ELSE BEGIN
                        SET @V_VRALIQIMPOSTOISS = 0;
                        SET @V_VRALIQIMPOSTOISSAUX = @V_VRALIQIMPOSTOISS;
                     END;
                  END;
               END;

               IF @V_VRALIQIMPOSTOISS > 5 BEGIN
                  --BLOCO DESTINADO AO RATEIO DA PARTE QUE PASSA DOS 5% DA ALQUOTA DO ISS ENTRE OS OUTROS IMPOSTOS
                  IF @V_FAIXAENQUADRADA IN (1, 2, 3, 4, 5) BEGIN
                     SET @V_VRALIQIMPOSTO = @V_VRALIQIMPOSTO + ((@V_VRALIQIMPOSTOISS - 5) * (@V_VRPERRATISSFAIXAAUX / 100));
                  END ELSE BEGIN 
                     IF @V_FAIXAENQUADRADA IN (6) BEGIN
                        SET @V_VRALIQIMPOSTO = @V_VRALIQIMPOSTO + ((@V_VRALIQIMPOSTOISS - 5) * (@V_VRPERRATISS5FAIXA / 100));
                     END;
                  END;

                  SET @V_VRALIQIMPOSTOISS = 5;
                  SET @V_RATEIADIFISS = 'S';
               END;
            END;
         END;

         IF @P_RATEIODIFERENCA = 'N' BEGIN
            --BLOCO DESTINADO AO CLCULO DA DIFERENA ENTRE A ALQUOTA EFETIVA ENCONTRADA E O SOMATRIO DAS ALQUOTAS ENCONTRADAS PARA CADA IMPOSTO QUE COMPOE A FAIXA DE FATURAMENTO
            --SEGUNDO A LEGISLAO, CASO EXISTA ESTA DIFERENA ESSE VALOR DEVER SER ACRESCIDO OU RETIRADO DO IMPOSTO DE MAIOR ALQUOTA NOMINAL
            SELECT @V_CDIMPOSTOMAXALIQUOTA = IM.CDIMPOSTONFE
              FROM IMPSIMPLESFAIXA I JOIN IMPOSTO IM ON (I.CDIMPOSTO = IM.CDIMPOSTO)
             WHERE I.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
               AND I.CDFAIXA = @V_CDFAIXAAUX
               AND I.VRALIQSIMPLES = (SELECT MAX(I.VRALIQSIMPLES)
                                        FROM IMPSIMPLESFAIXA I JOIN IMPOSTO IM ON (I.CDIMPOSTO = IM.CDIMPOSTO)
                                       WHERE I.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
                                         AND I.CDFAIXA = @V_CDFAIXAAUX
                                         AND IM.IDORGARRECAD = 'F'
                                         AND (((IM.CDIMPOSTONFE <> '31') AND (@V_RATEIADIFISS = 'S')) OR (@V_RATEIADIFISS = 'N')));
            IF (@V_CDIMPOSTOMAXALIQUOTA = @P_CDIMPOSTONFE) BEGIN
               --A IDIA AQUI  CHAMAR ESSA MESMA PROCEDURE PARA CADA IMPOSTO QUE COMPE A FAIXA DE VALORES E A ALQUOTA ENCONTRADA PARA CADA UM SER ARREDONDADA
               --PARA DUAS CASAS DECIMAIS E ADICIONADO A UMA VARIVEL. DEPOIS O VALOR DESTA VARIVEL SER COMPARADA AO VALOR DA ALQUOTA EFETIVA ENCONTRADA
               --LEMBRANDO QUE O SOMATRIO DAS ALQUOTAS ENCONTRADAS PARA CADA IMPOSTO DEVER SER IDNTICO A ALQUOTA EFETIVA ENCONTRADA
               SET @V_VRALIQSIMPLESRATEIO = 0;
               
               DECLARE C_RATEIO_IMPOSTO CURSOR FOR SELECT IM.CDIMPOSTONFE, I.VRALIQSIMPLES, I.VRPERRATISS
                                                     FROM IMPSIMPLESFAIXA I JOIN IMPOSTO IM ON (I.CDIMPOSTO = IM.CDIMPOSTO)
                                                    WHERE I.CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
                                                      AND I.CDFAIXA = @V_CDFAIXAAUX
                                                      AND (((IM.CDIMPOSTONFE <> '31') AND (@V_RATEIADIFISS = 'S')) OR (@V_RATEIADIFISS = 'N'))
                                                    ORDER BY IM.CDIMPOSTONFE
               OPEN C_RATEIO_IMPOSTO;
               FETCH NEXT FROM C_RATEIO_IMPOSTO INTO @C_RATEIO_IMPOSTO_CDIMPOSTONFE,
                                                     @C_RATEIO_IMPOSTO_VRALIQSIMPLES,
                                                     @C_RATEIO_IMPOSTO_VRPERRATISS;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  EXEC CALCULA_ALIQUOTA_SN @P_CDEMPRESA, 
                                           @P_CDTIPOOPER, 
                                           @P_INIVALID, 
                                           @P_CDFISOPEITEM, 
                                           @C_RATEIO_IMPOSTO_CDIMPOSTONFE, 
                                           @P_VRSUBLIMITESN,
                                           'S',
                                           @V_RBT12VALIDA,
                                           @V_RBAVALIDA,
                                           @V_CDSIMPLESNACIONALVALIDA,
                                           @V_CDFAIXAVALIDA,
                                           @V_VRALIQUOTASNVALIDA;

                  SET @V_VRALIQSIMPLESRATEIO = @V_VRALIQSIMPLESRATEIO + ROUND(@V_VRALIQUOTASNVALIDA, 2, 0);

                  FETCH NEXT FROM C_RATEIO_IMPOSTO INTO @C_RATEIO_IMPOSTO_CDIMPOSTONFE,
                                                        @C_RATEIO_IMPOSTO_VRALIQSIMPLES,
                                                        @C_RATEIO_IMPOSTO_VRPERRATISS;
               END;
               CLOSE C_RATEIO_IMPOSTO;
               DEALLOCATE C_RATEIO_IMPOSTO;

               IF @V_RATEIADIFISS = 'S' BEGIN
                  IF @V_FAIXAENQUADRADA = 6 BEGIN
                     IF (@V_VRALIQEFETIVAFAIXAAUX + @V_VRALIQIMPOSTOISSAUX) <> (@V_VRALIQSIMPLESRATEIO + 5) BEGIN
                        SET @V_VRALIQIMPOSTO = ROUND(@V_VRALIQIMPOSTO, 2, 0) + ((@V_VRALIQEFETIVAFAIXAAUX + @V_VRALIQIMPOSTOISSAUX) - (@V_VRALIQSIMPLESRATEIO + 5));
                     END;
                  END ELSE BEGIN
                     IF (@V_VRALIQEFETIVAFAIXAAUX - 5) <> @V_VRALIQSIMPLESRATEIO BEGIN
                        SET @V_VRALIQIMPOSTO = ROUND(@V_VRALIQIMPOSTO, 2, 0) + ((@V_VRALIQEFETIVAFAIXAAUX - 5) - @V_VRALIQSIMPLESRATEIO);
                     END;
                  END;
               END ELSE BEGIN
                  IF @V_RBA <= (@P_VRSUBLIMITESN * 1.2) BEGIN
                     IF @V_VRALIQEFETIVAFAIXAAUX <> @V_VRALIQSIMPLESRATEIO BEGIN
                        SET @V_VRALIQIMPOSTO = ROUND(@V_VRALIQIMPOSTO, 2, 0) + (@V_VRALIQEFETIVAFAIXAAUX - @V_VRALIQSIMPLESRATEIO);
                     END;
                  END ELSE BEGIN
                     IF (@V_VRALIQEFETIVAFAIXAAUX - @V_VRALIQIMPOSTOISSAUX) <> @V_VRALIQSIMPLESRATEIO BEGIN
                        SET @V_VRALIQIMPOSTO = ROUND(@V_VRALIQIMPOSTO, 2, 0) + (@V_VRALIQEFETIVAFAIXAAUX - @V_VRALIQIMPOSTOISSAUX - @V_VRALIQSIMPLESRATEIO);
                     END;
                  END;
               END;
            END;
         END;
         --PREENCHENDO OS PARMETROS DE SADA DA PROCEDURE
         SET @P_RBT12 = @V_RBT12;
         SET @P_RBA = @V_RBA;
         SET @P_CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL;
         SET @P_CDFAIXA = @V_CDFAIXAAUX;
         SET @P_VRALIQUOTASN = ISNULL(@V_VRALIQIMPOSTO, 0);
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CALCULA_ALIQUOTA_SN','6.05.xxx';
GO
